summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2017-10-12 20:46:42 +0200
committerChristian Grothoff <christian@grothoff.org>2017-10-12 20:46:42 +0200
commitcb13afaf54852a531362d08420a1c062f5f32efe (patch)
treebff636f3a917fd8d9451e4d4a012051df58a065d /src/include
parent600d1684e31a19219a44d751ce28469984dfe25b (diff)
downloadexchange-cb13afaf54852a531362d08420a1c062f5f32efe.tar.gz
exchange-cb13afaf54852a531362d08420a1c062f5f32efe.tar.bz2
exchange-cb13afaf54852a531362d08420a1c062f5f32efe.zip
complete first pass of taler-wre-auditor's wire-out audit logic
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_auditordb_plugin.h4
-rw-r--r--src/include/taler_wire_plugin.h6
2 files changed, 7 insertions, 3 deletions
diff --git a/src/include/taler_wire_plugin.h b/src/include/taler_wire_plugin.h
index 4134afc00..29d0c483a 100644
--- a/src/include/taler_wire_plugin.h
+++ b/src/include/taler_wire_plugin.h
@@ -59,7 +59,11 @@ struct TALER_WIRE_TransferDetails
struct GNUNET_TIME_Absolute execution_date;
/**
- * Reserve public key that was encoded in the wire transfer subject
+ * Reserve public key that was encoded in the wire transfer subject.
+ * FIXME: this is incorrect for *outgoing* wire transfers.
+ * Maybe use `struct TALER_WireTransferIdentifierRawP` here instead?
+ * OTOH, we might want to make this even more generic in case of
+ * invalid transfers, so that we can capture those as well!
*/
struct TALER_ReservePublicKeyP reserve_pub;
diff --git a/src/include/taler_auditordb_plugin.h b/src/include/taler_auditordb_plugin.h
index 08106e212..2d7d4600d 100644
--- a/src/include/taler_auditordb_plugin.h
+++ b/src/include/taler_auditordb_plugin.h
@@ -118,9 +118,9 @@ struct TALER_AUDITORDB_WireProgressPoint
uint64_t last_reserve_in_serial_id;
/**
* last_reserve_out_serial_id serial ID of the last reserve_out the wire auditor processed
*/
- uint64_t last_reserve_out_serial_id;
+ uint64_t last_wire_out_serial_id;
};
@@ -118,9 +118,9 @@ struct TALER_AUDITORDB_WireProgressPoint
uint64_t last_reserve_in_serial_id;
/**
- * last_reserve_out_serial_id serial ID of the last reserve_out the wire auditor processed
+ * last_wire_out_serial_id serial ID of the last wire_out the wire auditor processed
*/